@@ -1,7 +1,7 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 from sql import Cast, Literal
-from sql.functions import Position, Substring
+from sql.functions import CharLength, Position, Substring
 
 from trytond import backend
 from trytond.i18n import gettext
@@ -181,7 +181,7 @@ class Package(tree(), MeasurementsMixin, ModelSQL, ModelView):
     'Stock Package'
     __name__ = 'stock.package'
     _rec_name = 'code'
-    code = fields.Char('Code', select=True, readonly=True, required=True)
+    code = fields.Char('Code', readonly=True, required=True)
     company = fields.Many2One('company.company', "Company", required=True)
     type = fields.Many2One(
         'stock.package.type', "Type", required=True,
@@ -189,7 +189,7 @@ class Package(tree(), MeasurementsMixin, ModelSQL, ModelView):
             'readonly': Eval('state') == 'closed',
             })
     shipment = fields.Reference(
-        "Shipment", selection='get_shipment', select=True,
+        "Shipment", selection='get_shipment',
         states={
             'readonly': Eval('state') == 'closed',
             },
@@ -218,7 +218,7 @@ class Package(tree(), MeasurementsMixin, ModelSQL, ModelView):
             'readonly': Eval('state') == 'closed',
             })
     parent = fields.Many2One(
-        'stock.package', "Parent", select=True, ondelete='CASCADE',
+        'stock.package', "Parent", ondelete='CASCADE',
         domain=[
             ('company', '=', Eval('company', -1)),
             ('shipment', '=', Eval('shipment')),
@@ -240,6 +240,11 @@ class Package(tree(), MeasurementsMixin, ModelSQL, ModelView):
                 ('closed', "Closed"),
                 ], "State"), 'on_change_with_state')
 
+    @classmethod
+    def __setup__(cls):
+        cls.code.search_unaccented = False
+        super().__setup__()
+
     @classmethod
     def __register__(cls, module):
         pool = Pool()
@@ -266,6 +271,11 @@ class Package(tree(), MeasurementsMixin, ModelSQL, ModelView):
                         [table.company], [value],
                         where=table.shipment.like(name + ',%')))
 
+    @classmethod
+    def order_code(cls, tables):
+        table, _ = tables[None]
+        return [CharLength(table.code), table.code]
+
     @classmethod
     def default_company(cls):
         return Transaction().context.get('company')
@@ -361,7 +371,7 @@ class Type(MeasurementsMixin, DeactivableMixin, ModelSQL, ModelView):
 class Move(metaclass=PoolMeta):
     __name__ = 'stock.move'
     package = fields.Many2One(
-        'stock.package', "Package", select=True,
+        'stock.package', "Package", readonly=True,
         domain=[
             ('company', '=', Eval('company', -1)),
             ],
